import { ActivatedRoute, Router } from '@angular/router';
import { EventEmitter, OnInit, KeyValueDiffer, DoCheck, KeyValueDiffers } from '@angular/core';
import { Axle, AxleType, Tire, Vehicle } from './vehicle.model';
import * as i0 from "@angular/core";
/**
 * Component to display a vehicle shape
 * Axle could be display with it tires
 * The component allow click and select on an axle
 */
export declare class VehicleComponent implements OnInit, DoCheck {
    private readonly route;
    private readonly router;
    /**
     * Vehicle definition
     */
    vehicle: Vehicle;
    /**
     * Grow the vehicle (default = 1)
     */
    grow: number;
    /**
     * Allow tire selection
     */
    tireSelection: boolean;
    /**
     * Allow axle selection
     */
    axleSelection: boolean;
    /**
     * Position query parameter
     */
    positionQueryParameter: string;
    /**
     * Output when a tire is clicked
     */
    onPositionSelected: EventEmitter<number[]>;
    axles: Axle[];
    minAxleSize: number;
    selected: number[];
    axleRatio: number[];
    differ: KeyValueDiffer<string, any>;
    AxleType: typeof AxleType;
    query: string;
    constructor(route: ActivatedRoute, router: Router, differs: KeyValueDiffers);
    ngOnInit(): void;
    ngDoCheck(): void;
    init(): void;
    /**
     * Fill empty tires depending of max defined position
     *
     * @param axle
     * @param maxPosition
     * @returns
     */
    fillEmptyTires(axle: Axle, maxPosition: number): Tire[];
    /**
     * Determine first tire width from tire array
     */
    getFirstWidth(tires: Tire[]): number;
    /**
     * Axle selection method
     * Notify other with axle rank and tire position 0
     */
    selectAxle($event: Event, axleIdx: number): void;
    /**
     * Tire selection method
     * Notify other with axle rank and tire rank
     */
    selectTire(axleIdx: number, tireIdx: number): void;
    /**
     * Get axle style as CSS properties
     * Define margin with axle separated distance
     *
     * @param axleIndex
     * @returns
     */
    getAxleStyle(axleIndex: number): {
        'margin-top': string;
    };
    /**
     * Get style for axle regarding the vehicle configuration and growth
     *
     * @param ratios
     * @param axleIndex
     * @returns
     */
    getAxleLineStyle(ratios: number[], axleIndex: number): {
        'margin-top'?: undefined;
        'background-color'?: undefined;
    } | {
        'margin-top': string;
        'background-color': string;
    };
    /**
     * Get style for axle regarding the vehicle configuration and growth
     *
     * @param ratios
     * @param axleIndex
     * @returns
     */
    getAxleDistStyle(ratios: number[], axleIndex: number): {
        'background-size'?: undefined;
        height?: undefined;
        width?: undefined;
    } | {
        'background-size': string;
        height: string;
        width: string;
    };
    /**
     * Get axle scale from ratio
     * And apply margin
     */
    getTireStyle(ratios: number[], axleIndex: number, tireIndex: number, position: number): {
        width?: undefined;
        height?: undefined;
        'margin-right'?: undefined;
        'background-color'?: undefined;
    } | {
        width: string;
        height: string;
        'margin-right': string;
        'background-color': string;
    };
    static ɵfac: i0.ɵɵFactoryDeclaration<VehicleComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<VehicleComponent, "mic-vehicle", never, { "vehicle": "vehicle"; "grow": "grow"; "tireSelection": "tireSelection"; "axleSelection": "axleSelection"; "positionQueryParameter": "positionQueryParameter"; }, { "onPositionSelected": "onPositionSelected"; }, never, never, false, never>;
}
