import { Icon } from '@michelin/theme';
export declare enum AxleType {
    STEER = "STEER",
    DRIVE = "DRIVE",
    LIFT = "LIFT"
}
/**
 * Define a vehicle
 */
export declare class Vehicle {
    /**
     * Axle list that contain tires
     */
    axles?: Axle[];
    /**
     * Distance between axles
     */
    axleDist?: number[];
    /**
     * Axle width
     */
    axleTrack?: number[];
    constructor(vehicle: Partial<Vehicle>);
}
/**
 * Define an axle with type and tires
 */
export declare class Axle {
    /**
     * Axle key
     */
    key: number;
    /**
     * Tire list
     */
    tires: Tire[];
    /**
     * Axle type (STEER, DRIVE, LIFT)
     */
    type?: AxleType;
    /**
     * Override primary color for the axle
     */
    color?: string;
    /**
     * Axle informations
     */
    informations?: {
        /**
         * Main information text
         */
        text?: string;
        /**
         * Additional information text
         */
        subtext?: string;
    };
}
/**
 * Define a tire
 */
export declare class Tire {
    /**
     * Position on the axle
     */
    position?: number;
    /**
     * Width allow to grow tire (optional)
     */
    width?: number;
    /**
     * Override primary color for the tire
     */
    color?: string;
    /**
     * Icon
     */
    icon?: string | Icon;
    /**
     * Tire informations
     */
    informations?: {
        /**
         * Add tooltip on tire
         */
        tooltip?: string;
        /**
         * Main information text
         */
        text?: string;
        /**
         * Additional information text
         */
        subtext?: string;
        /**
         * Icon
         */
        icon?: string | Icon;
    };
}
